@@ -24,8 +24,8 @@ def weighted_argmax(logits):
     bins = logits.argmax(dim=1)
 
     # Find bounds of analysis window
-    start = torch.max(torch.tensor(0), bins - 4)
-    end = torch.min(torch.tensor(logits.size(2)), bins + 5)
+    start = torch.max(torch.tensor(0, device=logits.device), bins - 4)
+    end = torch.min(torch.tensor(logits.size(2), device=logits.device), bins + 5)
 
     # Mask out everything outside of window
     for batch in range(logits.size(0)):
@@ -69,8 +69,9 @@ def viterbi(logits):
     sequences = probs.cpu().numpy()
 
     # Perform viterbi decoding
-    bins = [librosa.sequence.viterbi(sequence, viterbi.transition)
-            for sequence in sequences]
+    bins = np.array([
+        librosa.sequence.viterbi(sequence, viterbi.transition).astype(np.int64)
+        for sequence in sequences])
 
     # Convert to pytorch
     bins = torch.tensor(bins, device=probs.device)
